"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const OperatingSystem = require("os");
const Path = require("path");
const Filesystem = require("fs");
exports.default = new class Storage {
    /**
     * Storage path.
     */
    get storagePath() {
        const path = Path.join(OperatingSystem.homedir(), 'desktop-spotlight');
        if (!Filesystem.existsSync(path)) {
            Filesystem.mkdirSync(path);
        }
        return path;
    }
    /**
     * Build file path to the given destination.
     *
     * @param to
     */
    path(to) {
        return Path.join(this.storagePath, to);
    }
    /**
     * Store a file stream.
     *
     * @param file
     */
    storeStream(file) {
        const path = this.path(file.name);
        file.stream.pipe(Filesystem.createWriteStream(path));
        return new Promise((resolve, reject) => {
            file.stream.on('end', () => resolve(path));
            file.stream.on('error', reject);
        });
    }
    /**
     * Shorten the given path.
     *
     * @param absolutePath
     */
    shortenPath(absolutePath) {
        return absolutePath.replace(OperatingSystem.homedir(), '~')
            .replace(/\\/g, '/');
    }
};
