"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
const Helpers_1 = require("./Helpers");
const Image_1 = require("./assets/Image");
exports.default = new class Wallpapers {
    /**
     * Wallpapers constructor
     */
    constructor() {
        /**
         * API cache.
         */
        this.cache = {
            share_key: null,
        };
        this.api = axios_1.default.create({
            baseURL: 'https://unsplash.com/napi/collections/1065976',
            headers: {
                'User-Agent': Helpers_1.default.userAgent,
            }
        });
    }
    /**
     * Fetch share key from collection API.
     */
    get shareKey() {
        return new Promise(async (resolve, reject) => {
            if (this.cache.share_key) {
                return this.cache.share_key;
            }
            const api = await this.api.get('/');
            resolve(this.cache.share_key = api.data.share_key);
        });
    }
    /**
     * Fetch images from the given page.
     *
     * @param page
     */
    async fetch(page = 1) {
        const imageRequest = await this.api.get('/photos', {
            params: {
                share_key: await this.shareKey,
                order_by: 'latest',
                per_page: 10,
                page,
            }
        });
        return imageRequest.data.map((imageData) => {
            return new Image_1.default(imageData);
        });
    }
    /**
     * Filter images to landscape mode.
     *
     * @param images
     */
    filterLandscape(images) {
        return images.filter(({ isLandscape }) => isLandscape);
    }
    /**
     * Fetch single image.
     */
    async single(landscapeOnly = true) {
        let page = Helpers_1.default.random(1, 80);
        let images = await this.fetch(page);
        if (landscapeOnly) {
            images = this.filterLandscape(images);
        }
        while (landscapeOnly && !images.length) {
            images = this.filterLandscape(await images(page += 1));
        }
        return Helpers_1.default.sample(images);
    }
};
