"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
const Mime = require("mime");
const Wallpaper = require("wallpaper");
const Storage_1 = require("../Storage");
class Image {
    /**
     * Image constructor.
     *
     * @param image
     */
    constructor(image) {
        this.image = image;
    }
    /**
     * Raw image stream.
     */
    get streamRequest() {
        return axios_1.default.get(this.image.urls.raw, {
            responseType: 'stream',
        });
    }
    /**
     * Whether or not the current image is in landscape mode.
     */
    get isLandscape() {
        return this.image.height < this.image.width;
    }
    /**
     * Photographer portfolio URL
     */
    get portfolio() {
        return this.image.user.portfolio_url || this.image.user.links.html;
    }
    /**
     * Store current image.
     */
    async store() {
        const { headers, data } = await this.streamRequest;
        return await Storage_1.default.storeStream({
            name: `${this.image.id}.${Mime.getExtension(headers['content-type'])}`,
            stream: data,
        });
    }
    /**
     * Set the current image as a wallpaper.
     */
    async setAsWallpaper() {
        const imagePath = await this.store();
        await Wallpaper.set(imagePath);
    }
}
exports.default = Image;
